/*
Copyright 2012,2013 Jun Wako <wakojun@gmail.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef KEYMAP_COMMON_H
#define KEYMAP_COMMON_H

#include <stdint.h>
#include <stdbool.h>
#include <avr/pgmspace.h>
#include "keycode.h"
#include "action.h"
#include "action_macro.h"
#include "report.h"
#include "host.h"
#include "print.h"
#include "debug.h"
#include "keymap.h"


extern const uint8_t keymaps[][MATRIX_ROWS][MATRIX_COLS];
extern const uint16_t fn_actions[];


/* DATALUXXX FULL SIZE 105 KEY

 */
#define KEYMAP( \
    K00,K01,K02,K03,K04,        K07,K08,K09,    K0B,K0C,K0D,K0E, \
	K10,K11,K12,K13,K14,        K17,K18,K19,    K1B,K1C,K1D,K1E, \
	K20,K21,K22,K23,K24,        K27,K28,K29,    K2B,K2C,K2D,K2E, \
	K30,K31,K32,K33,K34,                        K3B,    K3D,K3E, \
	K40,K41,K42,K43,K44,K45,K46,K47,K48,K49,K4A,K4B,K4C,    K4E, \
	K50,K51,K52,K53,    K55,K56,K57,K58,K59,K5A,K5B,K5C,K5D,K5E, \
	K60,K61,K62,    K64,K65,K66,K67,K68,K69,K6A,K6B,K6C,    K6E, \
	K70,    K72,K73,    K75,K76,K77,K78,K79,K7A,K7B,K7C,    K7E, \
	K80,K81,K82,                K87,            K8B,K8C,K8D,K8E \
) { \
{KC_##K00,KC_##K01,KC_##K02,KC_##K03,KC_##K04,   KC_NO,   KC_NO,KC_##K07,KC_##K08,KC_##K09,   KC_NO,KC_##K0B,KC_##K0C,KC_##K0D,KC_##K0E}, \
{KC_##K10,KC_##K11,KC_##K12,KC_##K13,KC_##K14,   KC_NO,   KC_NO,KC_##K17,KC_##K18,KC_##K19,   KC_NO,KC_##K1B,KC_##K1C,KC_##K1D,KC_##K1E}, \
{KC_##K20,KC_##K21,KC_##K22,KC_##K23,KC_##K24,   KC_NO,   KC_NO,KC_##K27,KC_##K28,KC_##K29,   KC_NO,KC_##K2B,KC_##K2C,KC_##K2D,KC_##K2E}, \
{KC_##K30,KC_##K31,KC_##K32,KC_##K33,KC_##K34,   KC_NO,   KC_NO,   KC_NO,   KC_NO,   KC_NO,   KC_NO,KC_##K3B,   KC_NO,KC_##K3D,KC_##K3E}, \
{KC_##K40,KC_##K41,KC_##K42,KC_##K43,KC_##K44,KC_##K45,KC_##K46,KC_##K47,KC_##K48,KC_##K49,KC_##K4A,KC_##K4B,KC_##K4C,   KC_NO,KC_##K4E}, \
{KC_##K50,KC_##K51,KC_##K52,KC_##K53,   KC_NO,KC_##K55,KC_##K56,KC_##K57,KC_##K58,KC_##K59,KC_##K5A,KC_##K5B,KC_##K5C,KC_##K5D,KC_##K5E}, \
{KC_##K60,KC_##K61,KC_##K62,   KC_NO,KC_##K64,KC_##K65,KC_##K66,KC_##K67,KC_##K68,KC_##K69,KC_##K6A,KC_##K6B,KC_##K6C,   KC_NO,KC_##K6E}, \
{KC_##K70,   KC_NO,KC_##K72,KC_##K73   ,KC_NO,KC_##K75,KC_##K76,KC_##K77,KC_##K78,KC_##K79,KC_##K7A,KC_##K7B,KC_##K7C,   KC_NO,KC_##K7E}, \
{KC_##K80,KC_##K81,KC_##K82,   KC_NO,   KC_NO,   KC_NO,   KC_NO,KC_##K87,   KC_NO,   KC_NO,   KC_NO,KC_##K8B,KC_##K8C,KC_##K8D,KC_##K8E} \
}

/* ANSI valiant. No extra keys for ISO */
/*
#define KEYMAP_ANSI( \
    K00, K01, K02, K03, K04, K05, K06, K07, K08, K09, K0A, K0B, K0C, K0D, \
    K10, K11, K12, K13, K14, K15, K16, K17, K18, K19, K1A, K1B, K1C, K1D, \
    K20, K21, K22, K23, K24, K25, K26, K27, K28, K29, K2A, K2B,      K2D, \
    K30, K32, K33, K34, K35, K36, K37, K38, K39, K3A, K3B,           K3D, \
    K40, K41, K42,           K45,                     K4A, K4B, K4C, K4D  \
) KEYMAP( \
    K00, K01, K02, K03, K04, K05, K06, K07, K08, K09, K0A, K0B, K0C, K0D, \
    K10, K11, K12, K13, K14, K15, K16, K17, K18, K19, K1A, K1B, K1C, K1D, \
    K20, K21, K22, K23, K24, K25, K26, K27, K28, K29, K2A, K2B, NO,  K2D, \
    K30, NO,  K32, K33, K34, K35, K36, K37, K38, K39, K3A, K3B, NO,  K3D, \
    K40, K41, K42,           K45,                NO,  K4A, K4B, K4C, K4D  \
)


#define KEYMAP_HHKB( \
    K00, K01, K02, K03, K04, K05, K06, K07, K08, K09, K0A, K0B, K0C, K0D, K49,\
    K10, K11, K12, K13, K14, K15, K16, K17, K18, K19, K1A, K1B, K1C, K1D, \
    K20, K21, K22, K23, K24, K25, K26, K27, K28, K29, K2A, K2B,      K2D, \
    K30, K32, K33, K34, K35, K36, K37, K38, K39, K3A, K3B,      K3D, K3C, \
    K40, K41, K42,           K45,                     K4A, K4B, K4C, K4D  \
) KEYMAP( \
    K00, K01, K02, K03, K04, K05, K06, K07, K08, K09, K0A, K0B, K0C, K0D, \
    K10, K11, K12, K13, K14, K15, K16, K17, K18, K19, K1A, K1B, K1C, K1D, \
    K20, K21, K22, K23, K24, K25, K26, K27, K28, K29, K2A, K2B, NO,  K2D, \
    K30, NO,  K32, K33, K34, K35, K36, K37, K38, K39, K3A, K3B, K3C, K3D, \
    K40, K41, K42,           K45,                K49, K4A, K4B, K4C, K4D  \
)
*/
#endif
